.. buildingspy documentation master file, created by
   sphinx-quickstart on Wed Jun  1 22:56:43 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

buildingspy
===========

*buildingspy* is a `Python <https://www.python.org/>`_
package that can be used to:

 - Run Modelica simulations using
   `OPTIMICA <https://www.modelon.com/products-services/modelon-creator-suite/optimica-compiler-toolkit/>`_
   or
   `Dymola <https://www.3ds.com/products-services/catia/products/dymola>`_.
 - Process ``*.mat`` output files that were generated by
   OPTIMICA, Dymola or
   `OpenModelica <https://www.openmodelica.org/>`_.
 - Run unit tests as part of the library development.
 - Refactor Modelica libraries.
 - Merge the `IBPSA <https://github.com/ibpsa/modelica-ibpsa>`_ library to other
   Modelica libraries.

The package provides functions
to extract data series from the output file for
further use in the python packages
`matplotlib <https://matplotlib.org/>`_
for plotting and
`SciPy <https://www.scipy.org/>`_ for scientific computing.

Contents:

.. toctree::
   :maxdepth: 2

   install
   simulate
   simulate_Dymola
   simulate_Optimica
   io
   fmi
   examples
   development
   legal
   acknowledgments
   revisions

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
